@@ -22,14 +22,21 @@
 #ifndef CGAL_IO_FILE_MEDIT_H
 #define CGAL_IO_FILE_MEDIT_H
 
+#include <CGAL/license/Mesh_3.h>
+
+
 #include <CGAL/Mesh_3/config.h>
 
 #include <iostream>
+#include <iomanip>
 #include <map>
 #include <set>
 #include <vector>
 #include <string>
 #include <CGAL/utility.h>
+#include <CGAL/basic.h>
+
+#include <boost/unordered_map.hpp>
 
 namespace CGAL {
 
@@ -74,15 +81,14 @@ public:
          ++cell_it)
     {
       // Add subdomain index in internal map if needed
-      if ( subdomain_map_.end() ==
-              subdomain_map_.find(r_c3t3_.subdomain_index(cell_it)) )
-      {
-        subdomain_map_.insert(std::make_pair(r_c3t3_.subdomain_index(cell_it),
-                                             index_counter));
+      std::pair<typename Subdomain_map::iterator, bool> is_insert_successful =
+          subdomain_map_.insert(std::make_pair(r_c3t3_.subdomain_index(cell_it),
+                                               index_counter));
+
+      if(is_insert_successful.second)
         ++index_counter;
-      }
     }
-    
+
     // Rebind indices in alphanumeric order
     index_counter = first_index + 1;
     for ( typename Subdomain_map::iterator mit = subdomain_map_.begin() ;
@@ -177,11 +183,8 @@ public:
         cell_it != r_c3t3_.cells_in_complex_end();
         ++cell_it)
     {
-      // Add subdomain index in set if new
-      if ( subdomain_set.end() == subdomain_set.find(subdomain_index(cell_it)) )
-      {
-        subdomain_set.insert(subdomain_index(cell_it));
-      }
+      // Add subdomain index in set
+      subdomain_set.insert(subdomain_index(cell_it));
     }
     
     return subdomain_set.size();
@@ -227,14 +230,11 @@ public:
         ++facet_it)
     {
       // Add surface index in internal map if needed
-      if ( surface_map_.end() ==
-          surface_map_.find(c3t3.surface_patch_index((*facet_it).first,
-                                                     (*facet_it).second)) )
-      {
-        surface_map_.insert(std::make_pair(r_c3t3_.surface_patch_index(*facet_it),
-                                           index_counter));
+      std::pair<typename Surface_map::iterator, bool> is_insert_successful =
+          surface_map_.insert(std::make_pair(r_c3t3_.surface_patch_index(*facet_it),
+                                             index_counter));
+      if(is_insert_successful.second)
         ++index_counter;
-      }
     }
     
     // Find cell_pmap_ unused indices
@@ -245,12 +245,8 @@ public:
         cell_it != r_c3t3_.cells_in_complex_end();
         ++cell_it)
     {
-      // Add subdomain index in set if new
-      if ( cell_label_set.end()
-          == cell_label_set.find(get(cell_pmap_,cell_it)) )
-      {
-        cell_label_set.insert(get(cell_pmap_,cell_it));
-      }
+      // Add subdomain index in set
+      cell_label_set.insert(get(cell_pmap_, cell_it));
     }
     
     // Rebind indices
@@ -787,7 +783,7 @@ output_to_medit(std::ostream& os,
   //-------------------------------------------------------
   os << "Vertices\n" << tr.number_of_vertices() << '\n';
 
-  std::map<Vertex_handle, int> V;
+  boost::unordered_map<Vertex_handle, int> V;
   int inum = 1;
   for( Finite_vertices_iterator vit = tr.finite_vertices_begin();
        vit != tr.finite_vertices_end();
